@@ -1,8 +1,7 @@
 package HTTP::Balancer::Command::List;
 use Modern::Perl;
 use Moose;
-with qw( HTTP::Balancer::Role::Command
-         HTTP::Balancer::Role::Stem );
+with qw( HTTP::Balancer::Role::Stem );
 
 use Text::Table;
 
